@@ -516,7 +516,7 @@ def plot(eco_code):
                            edgecolor='blue', linewidth=2)
             plt.gca().add_patch(poly)
     else:
-        x, y = coords[0].exterior.coords.xy
+        x, y = coords.exterior.coords.xy
         x = x.tolist()
         y = y.tolist()
         xym = list(zip(x, y))
