@@ -1,7 +1,6 @@
 import sys
-import os
-import pandas as pd
 
+import pandas as pd
 
 sys.path.append('..')
 
@@ -10,6 +9,9 @@ import marinvaders.readers as readers  # noqa: E402
 
 
 def test_ecoregions():
+    """
+    test existance and fields of ecoregion
+    """
     marine_ecoregions = ml.marine_ecoregions()
     assert len(marine_ecoregions) > 0
     assert ['ECO_CODE', 'ECO_CODE_X', 'ECOREGION',
@@ -18,6 +20,10 @@ def test_ecoregions():
 
 
 def test_species_class():
+    """
+    test instance of Species object for random species which we assume
+    is always present at obis
+    """
     ds = ml.Species(145634)
     assert ds.aphia_id == 145634
     assert len(ds.obis) > 0
@@ -25,11 +31,17 @@ def test_species_class():
 
 
 def test_marine_life_class():
+    """
+    test instance of MarineLife object for specific eco code
+    """
     marinelife = ml.MarineLife(20194)
     assert marinelife.eco_code == 20194
 
 
 def test_readers():
+    """
+    test data readers for different stored datasets
+    """
     ecomrgidlink = readers.eco_mrgid_link()
     assert isinstance(ecomrgidlink, pd.DataFrame)
     assert len(ecomrgidlink) > 0
